@@ -1,5 +1,5 @@
-## Fri Mar 07 18:39:01 2014
-## Original file Copyright © 2014 A.C. Guidoum, K. Boukhetala
+## Tue Jan 12 15:47:04 2016
+## Original file Copyright © 2016 A.C. Guidoum, K. Boukhetala
 ## This file is part of the R package Sim.DiffProc
 ## Department of Probabilities & Statistics
 ## Faculty of Mathematics
@@ -123,10 +123,13 @@ summary.rsde1d <- function(object, ...)
 							   sprintf("%f",moment(x,order=2)),sprintf("%f",moment(x,order=3)),sprintf("%f",moment(x,order=4)),
 							   sprintf("%f",moment(x,order=5)),sprintf("%f",bconfint(x)[1]),sprintf("%f",bconfint(x)[2])),
                                ncol=1))
-    rownames(res) <- paste(c("Mean","Variance","Median","First quartile","Third quartile",
+    # rownames(res) <- paste(c("Mean","Variance","Median","First quartile","Third quartile",
+                              # "Skewness","Kurtosis","Moment of order 2","Moment of order 3",
+                              # "Moment of order 4","Moment of order 5","Bound conf Inf (95%)","Bound conf Sup (95%)"),sep="")
+    # names(res) <- paste(c("x"),sep="")
+	dimnames(res) <- list(c("Mean","Variance","Median","First quartile","Third quartile",
                               "Skewness","Kurtosis","Moment of order 2","Moment of order 3",
-                              "Moment of order 4","Moment of order 5","Bound conf Inf (95%)","Bound conf Sup (95%)"),sep="")
-    names(res) <- paste(c("x"),sep="")
+                              "Moment of order 4","Moment of order 5","Bound conf Inf (95%)","Bound conf Sup (95%)"),c("x"))
     print(res, quote = FALSE, right = TRUE,...)
     invisible(object)
 }
@@ -259,10 +262,13 @@ summary.rsde2d <- function(object, ...)
                                sprintf("%f",skewness(y)),sprintf("%f",kurtosis(y)),sprintf("%f",moment(y,order=2)),sprintf("%f",moment(y,order=3)),
                                sprintf("%f",moment(y,order=4)),sprintf("%f",moment(y,order=5)),sprintf("%f",bconfint(y)[1]),sprintf("%f",bconfint(y)[2])),
                                ncol=2))
-    rownames(res) <- paste(c("Mean","Variance","Median","First quartile","Third quartile",
+    # rownames(res) <- paste(c("Mean","Variance","Median","First quartile","Third quartile",
+                              # "Skewness","Kurtosis","Moment of order 2","Moment of order 3",
+                              # "Moment of order 4","Moment of order 5","Bound conf Inf (95%)","Bound conf Sup (95%)"),sep="")
+    # names(res) <- paste(c("x","y"),sep="")
+	dimnames(res) <- list(c("Mean","Variance","Median","First quartile","Third quartile",
                               "Skewness","Kurtosis","Moment of order 2","Moment of order 3",
-                              "Moment of order 4","Moment of order 5","Bound conf Inf (95%)","Bound conf Sup (95%)"),sep="")
-    names(res) <- paste(c("x","y"),sep="")
+                              "Moment of order 4","Moment of order 5","Bound conf Inf (95%)","Bound conf Sup (95%)"),c("x","y"))
     print(res, quote = FALSE, right = TRUE,...)
     invisible(object)
 }
@@ -408,10 +414,13 @@ summary.rsde3d <- function(object, ...)
                                sprintf("%f",skewness(z)),sprintf("%f",kurtosis(z)),sprintf("%f",moment(z,order=2)),sprintf("%f",moment(z,order=3)),
                                sprintf("%f",moment(z,order=4)),sprintf("%f",moment(z,order=5)),sprintf("%f",bconfint(z)[1]),sprintf("%f",bconfint(z)[2])),
                                ncol=3))
-    rownames(res) <- paste(c("Mean","Variance","Median","First quartile","Third quartile",
+    # rownames(res) <- paste(c("Mean","Variance","Median","First quartile","Third quartile",
+                              # "Skewness","Kurtosis","Moment of order 2","Moment of order 3",
+                              # "Moment of order 4","Moment of order 5","Bound conf Inf (95%)","Bound conf Sup (95%)"),sep="")
+    # names(res) <- paste(c("x","y","z"),sep="")
+	dimnames(res) <- list(c("Mean","Variance","Median","First quartile","Third quartile",
                               "Skewness","Kurtosis","Moment of order 2","Moment of order 3",
-                              "Moment of order 4","Moment of order 5","Bound conf Inf (95%)","Bound conf Sup (95%)"),sep="")
-    names(res) <- paste(c("x","y","z"),sep="")
+                              "Moment of order 4","Moment of order 5","Bound conf Inf (95%)","Bound conf Sup (95%)"),c("x","y","z"))
     print(res, quote = FALSE, right = TRUE,...)
     invisible(object)
 }
